@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: setup_menu.c,v 1.58 2008/04/29 12:44:25 phintuka Exp $
+ * $Id: setup_menu.c,v 1.58.2.1 2008/10/18 10:41:06 phintuka Exp $
  *
  */
 
@@ -399,7 +399,7 @@ static const char * const tvtime_method[] =
 static const int tvtime_methods_count = (sizeof(tvtime_method)/sizeof(tvtime_method[0]) - 1);
 
 static const char * const tvtime_method_name[] =
-  {"Use Video-Out Driver",               // "use_vo_driver"
+  {trNOOP("Use Video-Out Driver"),       // "use_vo_driver"
    "Linear Interpolation",               // "Linear",
    "Linear Blend (mplayer)",             // "LinearBlend",
    "Greedy - Low motion (DScaler)",      // "Greedy",
@@ -418,8 +418,8 @@ static const char * const tvtime_pulldown[] =
     NULL};
 
 static const char * const tvtime_pulldown_name[] = 
-  { "None",
-    "Vector",
+  { trNOOP("none"),
+    trNOOP("vector"),
     NULL};
 
 static const char * const tvtime_framerate[] = 
@@ -429,9 +429,9 @@ static const char * const tvtime_framerate[] =
     NULL};
 
 static const char * const tvtime_framerate_name[] = 
-  { "Full",
-    "Half (top)",
-    "Half (bottom)",
+  { trNOOP("full"),
+    trNOOP("half (top)"),
+    trNOOP("half (bottom)"),
     NULL};
 
 struct tvtime_s {
