@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: playlist.c,v 1.17.2.1 2008/09/26 19:09:29 phintuka Exp $
+ * $Id: playlist.c,v 1.17.2.2 2009/02/12 11:20:24 phintuka Exp $
  *
  */
 
@@ -142,8 +142,10 @@ class cID3Scanner : public cThread
   {
     cPlaylistItem *Item = NULL;
     unsigned int Version = 0;
-
-    (void)nice(10);
+    const int priority = 10;
+    errno = 0;
+    if((nice(priority) == -1) && errno)
+      LOGDBG("ID3Scanner: Can't nice to value: %d", priority);
 
     LOGDBG("ID3Scanner Started");
     while(Running()) {
