@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: xine_sxfe_frontend.c,v 1.41.2.9 2008/10/26 07:35:17 phintuka Exp $
+ * $Id: xine_sxfe_frontend.c,v 1.41.2.10 2009/02/12 12:45:20 phintuka Exp $
  *
  */
 
@@ -309,7 +309,8 @@ static void set_above(sxfe_t *this, int stay_above)
       if(strstr(name, " (top)"))
 	*strstr(name, " (top)") = 0;
       if(stay_above)
-	asprintf(&newname, "%s (top)", name);
+	if (asprintf(&newname, "%s (top)", name) < 0)
+          newname = NULL;
       XStoreName(this->display, this->window[0], newname ?: name);
       XStoreName(this->display, this->window[1], newname ?: name);
       XFree(name);
